@@ -30,9 +30,33 @@ output=test-discard-range.out
 cleanup_fn rm -f $output
 
 export output
+
+# Limit to tail of file that is already sparse
 $NBDKIT -U - \
         data ' @1048576 1 @2097152 1 ' size=1G \
         --run ' nbddiscard -y "$uri" -o 512M -l 512M &&
                 nbdinfo --map "$uri" > $output '
 
 cat $output
+define expect <<\EOF
+         0     1048576    3  hole,zero
+   1048576       32768    0  data
+   1081344     1015808    3  hole,zero
+   2097152       32768    0  data
+   2129920  1071611904    3  hole,zero
+EOF
+printf %s "$expect" | diff -u - $output
+
+# Limit to head of file to see a change
+$NBDKIT -U - \
+        data ' @1048576 1 @2097152 1 ' size=1G \
+        --run ' nbddiscard -y "$uri" -l 2M &&
+                nbdinfo --map "$uri" > $output '
+
+cat $output
+define expect <<\EOF
+         0     2097152    3  hole,zero
+   2097152       32768    0  data
+   2129920  1071611904    3  hole,zero
+EOF
+printf %s "$expect" | diff -u - $output
