@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # nbd client library in userspace
-# Copyright (C) 2019 Red Hat Inc.
+# Copyright Red Hat
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -28,7 +28,7 @@ cleanup_fn rm -f $output
 $VG nbdsh --long-options > $output
 if [ $? != 0 ]; then
     echo "$0: unexpected exit status"
-    fail=1
+    exit 1
 fi
 cat $output
 grep -- --command $output
